History
-------

0.7.0 (2018-10-25)
++++++++++++++++++

- Added pu.db support
- Fixed pytest 3.7.3+ compatibility
- Switched to semantic versioning
- Build package wheels

0.6 (2018-02-13)
++++++++++++++++

- Fixed pytest 3.3.1+ compatibility (by `@noirbizarre <https://github.com/noirbizarre>`_)

0.5 (2017-02-25)
++++++++++++++++

- Fixed pypi package by adding MANIFEST.in

0.4 (2017-02-24)
++++++++++++++++

- Use post mortem on exception (by `@Wilfred <https://github.com/Wilfred>`_)

0.2 (2016-09-24)
++++++++++++++++

- Added ``import pytest.b`` support

0.1 (2016-07-31)
++++++++++++++++

- Public release